#!/usr/bin/env python3
import sys
import tomllib
import json

if len(sys.argv) != 3:
    print("usage: {sys.argv[0]} <input-toml> <output-json>")
    sys.exit(1)

toml_file = sys.argv[1]
json_file = sys.argv[2]

with open(toml_file, "rb") as fp:
    data = tomllib.load(fp)

# Remove redundant sections from config data

# The "package" section is used by official build process - application
# itself does not need it.
data.pop("package", None)

# Remove non-linux manifest paths from "store" entries.
for store in data["store"].values():
    paths = store["msg_manifest_paths"]
    paths.pop("windows", None)
    paths.pop("mac", None)

# Original config also includes "target" section, but we patch the
# application to return dynamically-determined values instead.

# Write
with open(json_file, "w") as fp:
    json.dump(data, fp, indent=2)
